RpcHandlerDummy

Struct RpcHandlerDummy 

pub struct RpcHandlerDummy {
    pub restricted: bool,
}
Available on crate feature dummy only.
An RpcHandler that always returns Default::default.

This struct implements RpcHandler, and always responds with the response struct set to Default::default.

See the crate documentation for example usage.

This is mostly used for testing purposes and can be disabled by disable the dummy feature flag.

Fields

restricted: bool

Should this RPC server be restricted?

The dummy will honor this bool on restricted methods/endpoints.